@@ -6,13 +6,12 @@ use v5.9.3;
 use strict;
 use warnings;
 
-require Exporter;
-require XSLoader;
+use Exporter 5.57 qw( import );
+use XSLoader;
 
-our @ISA = qw(Exporter);
 our @EXPORT_OK = qw(minify minify_utf8 minify_ascii);
 
-our $VERSION = 'v0.6.0';
+our $VERSION = 'v0.6.1';
 
 XSLoader::load( "Text::Minify::XS", $VERSION );
 
@@ -35,7 +34,7 @@ Text::Minify::XS - remove indentation and trailing whitespace
 
 =head1 VERSION
 
-version v0.6.0
+version v0.6.1
 
 =head1 SYNOPSIS
 
